from tkinter import messagebox

def deskripsi():
    """
    Fungsi untuk mencetak deskripsi kode program ke konsol
    dan menampilkan informasi nama kelompok menggunakan messagebox.
    """
    description = "Kode tersebut merupakan implementasi aplikasi absensi menggunakan OpenCV dan Tkinter. \n\nAplikasi ini memungkinkan pengguna untuk menambahkan data wajah mahasiswa, melakukan absensi melalui kamera, dan menyimpan hasil absensi ke dalam file Excel. \n\nDengan antarmuka pengguna yang bersih dan tombol tambahan tampilkan deskripsi yang memberikan notifikasi, aplikasi ini menyediakan pengalaman pengguna yang intuitif."
    print(description)

    messagebox.showinfo("Milik Kelompok 2:", description)



from setuptools import setup, find_packages
from pathlib import Path

VERSION = '0.1'
DESCRIPTION = 'Kelompok 2'

this_directory = Path(__file__).parent
LONG_DESCRIPTION = (this_directory / 'README.md').read_text()

# Setting up
setup(
    name="librarykelompok-2",
    version=VERSION,
    author="hanifaslamm",
    author_email="aslamhanif141@gmail.com",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url='https://github.com/hanifaslamm',
    packages=find_packages(),
    license='MIT',
    install_requires=[],
    keywords=['Hello'],
    classifiers=[
        'Development Status :: 1 - Planning',
    ],
)